boofun.core.partial
===================

.. automodule:: boofun.core.partial


   .. rubric:: Functions

   .. autosummary::

      partial

   .. rubric:: Classes

   .. autosummary::

      PartialBooleanFunction
